@@ -5,13 +5,15 @@ import json
 import yaml
 import gzip
 from copy import deepcopy
-from .revision import ProjectRevision
-from .jobDefinitions import JOB_DEFINITIONS
-from ..runner import Runner
-from ..utils import request, fileLoad
+from ..model.revision import ModelRevision
+from ..model.jobDefinitions import JOB_DEFINITIONS
+from ..utils import request, fileLoad, graphql_request
+from ..model import Model
+from deprecated import deprecated
 
 
-class Project(object):
+@deprecated(version='3.0', reason="该类将在 5.0 版本移除，请使用 Model 类代替")
+class Project(Model):
     """
         CloudPSS工程类，用于处理加载后的工程数据
 
@@ -38,7 +40,7 @@ class Project(object):
         """
         for k, v in project.items():
             if k == 'revision':
-                self.__dict__[k] = ProjectRevision(v)
+                self.__dict__[k] = ModelRevision(v)
             else:
                 self.__dict__[k] = v
 
@@ -79,13 +81,14 @@ class Project(object):
 
             :return: 按照元件的 rid 过滤后的 dict<>
 
-            >>> project.getComponentsByRid('project/CloudPSS/newInductorRouter')
+            >>> project.getComponentsByRid('model/CloudPSS/newInductorRouter')
             {
                 'canvas_0_2': Component 实例
             }
 
         """
-
+        if rid.startswith('project/'):
+            rid = rid.replace('project/', 'model/')
         v = self.getAllComponents()
 
         cells = {}
@@ -212,6 +215,8 @@ class Project(object):
         return config
 
     @staticmethod
+    @deprecated(version='3.0',
+                reason="该方法将在 5.0 版本移除，请使用 Model.fetchMany 方法代替")
     def fetchMany(name=None, pageSize=10, pageOffset=0):
         """
             获取用户可以运行的项目列表
@@ -224,7 +229,7 @@ class Project(object):
 
             >>> data=Project.fetchMany()
             [
-                {'rid': 'project/admin/share-test', 'name': '1234', 'description': '1234'}
+                {'rid': 'project/Demo/share-test', 'name': '1234', 'description': '1234'}
                 ...
             ]
         """
@@ -245,6 +250,7 @@ class Project(object):
         } for val in projectList]
 
     @staticmethod
+    @deprecated(version='3.0', reason="该方法将在 5.0 版本移除，请使用 Model.fetch 方法代替")
     def fetch(rid):
         """
             获取项目
@@ -256,43 +262,36 @@ class Project(object):
             >>> project=Project.fetch('project/Demo/test')
 
         """
+        if rid.startswith('project/'):
+            rid = rid.replace('project/', 'model/')
         query = """
-            query  t($rid:String!){
-                project(rid: $rid) {
-                    rid
-                    name
-                    revisionHash
-                    jobs
+            query  t($rid:ResourceId!){
+                model(input:{rid: $rid}) {
                     configs
                     context
-                    tags
                     description
+                    jobs
+                    name
+                    rid
+                    tags
                     revision {
-                        hash
-                        graphic
-                        documentation
                         author
-                        committer
-                        implements {
-                            diagram
-                        }
+                        documentation
+                        graphic
+                        hash
+                        implements
                         message
                         parameters
                         pins
+                        version
                     }
                 }
             }
         """
-        payload = {'query': query, 'variables': {'rid': rid}}
-        r = request('POST', 'graphql', data=json.dumps(payload))
-
-        data = json.loads(r.text)
-
-        if data['data'] is None:
-
+        data = graphql_request(query, {'rid': rid})
+        if "errors" in data:
             raise Exception(data['errors'][0]['message'])
-
-        return Project(data['data']['project'])
+        return Project(data['data']['model'])
 
     def run(self, job=None, config=None, name=None, **kwargs):
         """
@@ -315,10 +314,25 @@ class Project(object):
         if config is None:
             currentConfig = self.context['currentConfig']
             config = self.configs[currentConfig]
-
+        # output_channels= job['args']['output_channels']
+        output_channels = []
+        if 'output_channels' in job['args']:
+            for output in job['args']['output_channels']:
+                if type(output) is list and len(output) > 0:
+                    output_channels.append({
+                        '0': output[0],
+                        '1': output[1],
+                        '2': output[2],
+                        '3': output[3],
+                        '4': output[4].split(','),
+                    })
+                    continue
+                output_channels.append(output)
+        job['args']['output_channels'] = output_channels
         return self.revision.run(job, config, name, self.rid, **kwargs)
 
     @staticmethod
+    @deprecated(version='3.0', reason="该方法将在 5.0 版本移除，请使用 Model.load 方法代替")
     def load(filePath):
         """
             加载本地项目文件
@@ -337,6 +351,7 @@ class Project(object):
         return Project(data)
 
     @staticmethod
+    @deprecated(version='3.0', reason="该方法将在 5.0 版本移除，请使用 Model.dump 方法代替")
     def dump(project, file):
         """
             下载项目文件
@@ -402,6 +417,7 @@ class Project(object):
         return Project.update(self)
 
     @staticmethod
+    @deprecated(version='3.0', reason="该方法将在 5.0 版本移除，请使用 Model.create 方法代替")
     def create(project):
         """
             新建项目 
@@ -416,6 +432,7 @@ class Project(object):
         Project.update(project)
 
     @staticmethod
+    @deprecated(version='3.0', reason="该方法将在 5.0 版本移除，请使用 Model.update 方法代替")
     def update(project):
         """
             更新项目 
@@ -435,48 +452,39 @@ class Project(object):
             raise Exception('rid 错误，无法保存')
         elif owner[0] != username:
             raise Exception('rid 错误，无法保存')
-        revision = ProjectRevision.create(project.revision,
-                                          project.revision.hash)
-        projectQuery = """
-            mutation t(
-                $rid: String!,
-                $revisionHash: String!,
-                $context: JSONObject,
-                $configs: [JSONObject!]!,
-                $jobs: [JSONObject!]!,
-                $info:ProjectInfoInput!
-            ){
-                addProject( project:{rid: $rid,revisionHash:$revisionHash,configs:$configs,context:$context,jobs:$jobs},info:$info) {
-                    rid  
-                }
-            }
-        """
+
+        modelQuery = """
+                    mutation($a:UpdateModelInput!){updateModel(input:$a){
+                                         rid
+                                }}
+                """
         isPublic = project.context.get('auth', '') != 'private'
         isComponent = project.context.get('category', '') == 'component'
         publicRead = project.context.get('publicRead', '') != False
-        auth = {
-            'read': isPublic and (publicRead if isComponent else True),
-            'execute': isPublic,
-        }
-        payload = {
-            'query': projectQuery,
-            'variables': {
-                'rid': project.rid,
-                'revisionHash': revision['hash'],
-                'context': project.context,
-                'configs': project.configs,
-                'jobs': project.jobs,
-                'info': {
+
+        auth = (65539 if publicRead else 65537) if isPublic else 0
+        project.revision.author = username
+        revision = ModelRevision.create(project.revision,
+                                        project.revision.hash)
+
+        return graphql_request(
+            modelQuery, {
+                'a': {
+                    'rid': project.rid,
+                    'revision': revision['hash'],
+                    'context': project.context,
+                    'configs': project.configs,
+                    'jobs': project.jobs,
                     'name': project.name,
                     'description': project.description,
                     'tags': project.tags,
-                    'auth': auth,
-                },
-            }
-        }
-        r = request('POST', 'graphql', data=json.dumps(payload))
-        r = json.loads(r.text)
-        return r
+                    "permissions": {
+                        "moderator": 1,
+                        "member": 1,
+                        "everyone": auth,
+                    },
+                }
+            })
 
     def fetchTopology(
         self,
@@ -493,7 +501,7 @@ class Project(object):
 
             :return:  一个拓扑实例
 
-            >>> topology=project.fetchTopology() 
+            >>> topology=project.fetchTopology()
                 topology=project.fetchTopology(implementType='powerFlow',config=config) # 获取潮流实现的拓扑数据
                 topology=project.fetchTopology(maximumDepth=2) # 获取仅展开 2 层的拓扑数据
         """
