@@ -27,6 +27,4 @@ def verifyToken(token):
     result = jwt.decode(token, public_key, algorithms='RS256')
     if result['exp'] - int(time.time()) < 0:
         raise Exception('token 已过期，请重新申请')
-    if result.get('type', '') != 'SDK':
-        raise Exception('token 错误，请使用正确的 token')
     return result
